# Text-related datasets

This [datamaestro](https://github.com/experimaestro/datamaestro) plugin covers image-related datasets.


The list of available datasets and usage instruction can be found in the [documentation](https://experimaestro.github.io/datamaestro_image/).
